/*=====================================================================*/
/*    serrano/prgm/project/bigloo/bigloo/runtime/Clib/ceval.c          */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Fri Sep 24 10:20:30 1993                          */
/*    Last change :  Tue Jul 11 17:05:47 2023 (serrano)                */
/*    -------------------------------------------------------------    */
/*    Quelques petites fonctions pour l'interprete (principalement     */
/*    des fonctions de debug et de trace)                              */
/*=====================================================================*/
#include <bigloo.h>

/*---------------------------------------------------------------------*/
/*    void                                                             */
/*    bgl_init_eval_cnst ...                                           */
/*---------------------------------------------------------------------*/
void
bgl_init_eval_cnst() {
   ;
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_0 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_0(obj_t fun) {
   return BGL_PROCEDURE_CALL0(fun);
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_1 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_1(obj_t fun, obj_t a0) {
   return BGL_PROCEDURE_CALL1(fun, a0);
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_2 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_2(obj_t fun, obj_t a0, obj_t a1) {
   return BGL_PROCEDURE_CALL2(fun, a0, a1);
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_3 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_3(obj_t fun, obj_t a0, obj_t a1, obj_t a2) {
   return BGL_PROCEDURE_CALL3(fun, a0, a1, a2);
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_4 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_4(obj_t fun, obj_t a0, obj_t a1, obj_t a2, obj_t a3) {
   return BGL_PROCEDURE_CALL4(fun, a0, a1, a2, a3);
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    eval_apply ...                                                   */
/*---------------------------------------------------------------------*/
BGL_RUNTIME_DEF
obj_t
eval_apply(obj_t fun, obj_t list) {
   return apply(fun, list);
}
